import json
import uuid

import h2o_mlops_client as mlops

# Defines MLOps API URL. The address for the MLOps Gateway component.
# Usually: "https://api.mlops.my.domain"
MLOPS_API_URL = ""

# Defines IDP's token endpoint URL. For deployments using Keycloak as IDP:
# https://mlops.keycloak.domain/auth/realms/[fill-in-realm-name]/protocol/openid-connect/token
TOKEN_ENDPOINT_URL = ""

# Defines user's refresh token.
REFRESH_TOKEN = ""

# Sets client id for authentication.
CLIENT_ID = ""

# Sets client secret for authentication.
CLIENT_SECRET = ""

# Sets registered model id. 
REGISTERED_MODEL_ID = ""


# Count the model versions for the given registered model.
def count_model_version(
    mlops_client: mlops.Client,
    count_model_versions_request: mlops.StorageCountModelVersionsRequest):

    return mlops_client.storage.registered_model_version.count_model_versions(count_model_versions_request)


def count_model_version_request(registered_model_id):
    return mlops.StorageCountModelVersionsRequest(
        registered_model_id=registered_model_id
    )


def main():
    # Set up the token provider using an existing refresh token.
    mlops_token_provider = mlops.TokenProvider(
        refresh_token=REFRESH_TOKEN,
        client_id=CLIENT_ID,
        client_secret=CLIENT_SECRET,
        token_endpoint_url=TOKEN_ENDPOINT_URL,
    )

    # Set up the MLOps client.
    mlops_client = mlops.Client(
        gateway_url=MLOPS_API_URL,
        token_provider=mlops_token_provider,
    )

    # Count the registered model versions for the given registered model.
    count_model_version_response: mlops.StorageCountModelVersionsRequest = count_model_version(
        mlops_client=mlops_client, count_model_versions_request=count_model_version_request(
            registered_model_id=REGISTERED_MODEL_ID
        )
    )
    print(count_model_version_response)


if __name__ == "__main__":
    main()